Module filter

Module filter 

Structs

FilterSummary
Filter test results and return summary statistics.
TestFilter
A compiled test filter that can match test cases by name pattern.

Enums

FilterPattern
A single filter pattern that can match test names.
GlobSegment
A segment in a glob pattern.

Functions

build_filter
Build a TestFilter from filter configuration strings.
failed_test_names
Extract a list of failed test names from a result for re-running.
filter_with_summary
Apply filter and compute summary statistics.
matching_test_names
Extract test names matching a filter.