pub fn failed_test_names(result: &TestRunResult) -> Vec<String>Expand description
Extract a list of failed test names from a result for re-running.
pub fn failed_test_names(result: &TestRunResult) -> Vec<String>Extract a list of failed test names from a result for re-running.