pub struct TestFilter { /* private fields */ }Expand description
A compiled test filter that can match test cases by name pattern.
Implementations
Sourceimpl TestFilter
impl TestFilter
Sourcepub fn include_csv(self, patterns: &str) -> Self
pub fn include_csv(self, patterns: &str) -> Self
Add multiple include patterns from a comma-separated string.
Sourcepub fn exclude_csv(self, patterns: &str) -> Self
pub fn exclude_csv(self, patterns: &str) -> Self
Add multiple exclude patterns from a comma-separated string.
Sourcepub fn status(self, status: TestStatus) -> Self
pub fn status(self, status: TestStatus) -> Self
Only show tests with the given status.
Sourcepub fn matches(&self, test: &TestCase, suite_name: &str) -> bool
pub fn matches(&self, test: &TestCase, suite_name: &str) -> bool
Check if a test case matches this filter.
Sourcepub fn apply(&self, result: &TestRunResult) -> TestRunResult
pub fn apply(&self, result: &TestRunResult) -> TestRunResult
Apply this filter to a test run result, returning a filtered copy.