TestHistory

Struct TestHistory 

pub struct TestHistory { /* private fields */ }
Test history store backed by JSON files.

Implementations

Source

impl TestHistory

pub fn open(dir: &Path) -> Result<Self>

Open or create a history store in the given directory.

pub fn new_in_memory() -> Self

Create a new in-memory history (for testing).

pub fn record(&mut self, result: &TestRunResult) -> Result<()>

Record a test run result.

pub fn run_count(&self) -> usize

Get the number of recorded runs.

pub fn runs(&self) -> &[RunRecord]

Get all run records.

pub fn recent_runs(&self, n: usize) -> &[RunRecord]

Get the most recent N runs.

pub fn get_trend(&self, test_name: &str, last_n: usize) -> Vec<TestTrend>

Get trend data for a specific test.

pub fn get_flaky_tests( &self, min_runs: usize, max_pass_rate: f64, ) -> Vec<FlakyTest>

Get flaky tests (tests that alternate between pass and fail).

Get tests that are getting slower over time.

pub fn prune(&mut self, keep: usize) -> Result<usize>

Prune old entries, keeping only the most recent N.

pub fn pass_rate(&self, last_n: usize) -> f64

Get the overall pass rate over recent runs.

pub fn avg_duration(&self, last_n: usize) -> Duration

Get the average duration over recent runs.