Module impact

Module impact 

Structs

ImpactAnalysis
Result of impact analysis.

Enums

DiffMode
Get the list of files changed according to git.

Functions

analyze_impact
Analyze changed files to determine test impact.
format_impact
Format impact analysis for display.
get_changed_files
Get changed files from git diff.
is_git_repo
Check if git is available and the project is a git repository.