pub struct WorkPartition {
pub worker_id: usize,
pub test_groups: Vec<TestGroup>,
}Expand description
A partition of work to be executed by a single worker.
Fields
worker_id: usizeWorker index (0-based)
test_groups: Vec<TestGroup>Suite name to test name mapping for this partition
Implementations
Sourceimpl WorkPartition
impl WorkPartition