pub fn fuzzy_match(query: &str, items: &[String]) -> Vec<ScoredMatch>Expand description
Perform fuzzy matching of a query against a list of items. Returns items sorted by score (best match first).
pub fn fuzzy_match(query: &str, items: &[String]) -> Vec<ScoredMatch>Perform fuzzy matching of a query against a list of items. Returns items sorted by score (best match first).