pub fn parse_script_output(
parser: &OutputParser,
stdout: &str,
stderr: &str,
exit_code: i32,
) -> TestRunResultExpand description
Parse output from a script adapter using the configured parser.
pub fn parse_script_output(
parser: &OutputParser,
stdout: &str,
stderr: &str,
exit_code: i32,
) -> TestRunResultParse output from a script adapter using the configured parser.