RetryConfig

Struct RetryConfig 

pub struct RetryConfig {
    pub max_retries: u32,
    pub backoff: BackoffStrategy,
    pub stop_on_pass: bool,
    pub retry_failed_only: bool,
}
Configuration for retry behavior.

Fields

max_retries: u32

Maximum number of retries (0 = no retries)

backoff: BackoffStrategy

Backoff strategy between retries

stop_on_pass: bool

Whether to stop retrying a test after it passes once

retry_failed_only: bool

Whether to retry only failed tests (vs. retry entire suite)

Implementations

Source

impl RetryConfig

pub fn new(max_retries: u32) -> Self

Create a new retry config with the given max retries.

pub fn with_backoff(self, backoff: BackoffStrategy) -> Self

Set the backoff strategy.

pub fn with_stop_on_pass(self, stop: bool) -> Self

Set whether to stop on first pass.

pub fn with_retry_failed_only(self, failed_only: bool) -> Self

Set whether to retry failed tests only.

pub fn is_enabled(&self) -> bool

Returns true if retries are enabled.