pub struct WatchRunner { /* private fields */ }Expand description
The main watch mode runner loop.
Orchestrates file watching, terminal input, and test execution in a continuous loop until the user quits.
Implementations
Sourceimpl WatchRunner
impl WatchRunner
Sourcepub fn new(
project_dir: PathBuf,
runner_config: RunnerConfig,
options: WatchRunnerOptions,
) -> Self
pub fn new( project_dir: PathBuf, runner_config: RunnerConfig, options: WatchRunnerOptions, ) -> Self
Create a new WatchRunner.
Sourcepub fn from_config(project_dir: PathBuf, config: &Config) -> Self
pub fn from_config(project_dir: PathBuf, config: &Config) -> Self
Create a WatchRunner from a Config file.
Sourcepub fn stats(&self) -> &WatchStats
pub fn stats(&self) -> &WatchStats
Get current watch statistics.
Sourcepub fn failed_tests(&self) -> &[String]
pub fn failed_tests(&self) -> &[String]
Get the list of tests that failed in the last run.
Sourcepub fn start(&mut self, watch_config: &WatchConfig) -> Result<WatchStats>
pub fn start(&mut self, watch_config: &WatchConfig) -> Result<WatchStats>
Start the watch mode loop.
This method blocks until the user presses ‘q’ or max_runs is reached. Returns the final watch statistics.