pub struct DetectionEngine { /* private fields */ }Implementations
Sourceimpl DetectionEngine
impl DetectionEngine
pub fn new() -> Self
Sourcepub fn detect(&self, project_dir: &Path) -> Option<DetectedProject>
pub fn detect(&self, project_dir: &Path) -> Option<DetectedProject>
Detect the best matching test framework for the given project directory. Returns the detection result and a reference to the matching adapter.
Sourcepub fn detect_all(&self, project_dir: &Path) -> Vec<DetectedProject>
pub fn detect_all(&self, project_dir: &Path) -> Vec<DetectedProject>
Detect all matching frameworks (for polyglot projects).
Sourcepub fn adapter(&self, index: usize) -> &dyn TestAdapter
pub fn adapter(&self, index: usize) -> &dyn TestAdapter
Get an adapter by index.
Sourcepub fn adapters(&self) -> &[Box<dyn TestAdapter>]
pub fn adapters(&self) -> &[Box<dyn TestAdapter>]
Get all registered adapters.