Structs
- Impact
Analysis - Result of impact analysis.
Enums
- Diff
Mode - Get the list of files changed according to git.
Functions
- analyze_
impact - Analyze changed files to determine test impact.
- format_
impact - Format impact analysis for display.
- get_
changed_ files - Get changed files from git diff.
- is_
git_ repo - Check if git is available and the project is a git repository.