Script-based custom adapter for user-defined test frameworks.
Users can define custom adapters in testx.toml that run arbitrary commands and parse output in a standard format (JSON, JUnit XML, TAP, or line-based).
Structs
- Regex
Parser Config - Configuration for regex-based output parsing.
- Script
Adapter Config - Definition of a custom script adapter from config.
Enums
- Output
Parser - Output parser type for a script adapter.
Functions
- parse_
script_ output - Parse output from a script adapter using the configured parser.