pub struct FileWatcher { /* private fields */ }Expand description
File system watcher that detects changes in a project directory.
Implementations
Sourceimpl FileWatcher
impl FileWatcher
Sourcepub fn new(root: &Path, config: &WatchConfig) -> Result<Self>
pub fn new(root: &Path, config: &WatchConfig) -> Result<Self>
Create a new file watcher for the given directory.
Sourcepub fn wait_for_changes(&mut self) -> Vec<PathBuf>
pub fn wait_for_changes(&mut self) -> Vec<PathBuf>
Wait for file changes and return the changed paths (debounced). This blocks until changes are detected.