WatchStats

Struct WatchStats 

pub struct WatchStats {
    pub total_runs: u32,
    pub failed_runs: u32,
    pub passed_runs: u32,
    pub last_run: Option<Instant>,
    pub last_duration: Option<Duration>,
    pub last_failures: u32,
    pub last_passed: u32,
}
Statistics tracked across watch mode re-runs.

Fields

total_runs: u32

Total number of re-runs performed.

failed_runs: u32

Number of runs that had failures.

passed_runs: u32

Number of runs that passed completely.

last_run: Option<Instant>

Time of the last run.

last_duration: Option<Duration>

Duration of the last run.

last_failures: u32

Number of tests that failed in the last run.

last_passed: u32

Number of tests that passed in the last run.

Implementations

Source

impl WatchStats

pub fn new() -> Self

pub fn record_run(&mut self, result: &TestRunResult, duration: Duration)

Record the result of a test run.

pub fn summary(&self) -> String

Format a summary line for display.